@@ -2,7 +2,7 @@
 #
 # Redland.pm - Redland top level Perl module
 #
-# $Id: Redland.pm,v 1.22 2005/02/22 21:28:51 cmdjb Exp $
+# $Id: Redland.pm.in,v 1.28 2005/06/10 09:44:59 cmdjb Exp $
 #
 # Copyright (C) 2000-2004 David Beckett - http://purl.org/net/dajobe/
 # Institute for Learning and Research Technology - http://www.ilrt.bris.ac.uk/
@@ -23,6 +23,10 @@
 use RDF::Redland::Iterator;
 use RDF::Redland::Model;
 use RDF::Redland::Node;
+use RDF::Redland::BlankNode;
+use RDF::Redland::URINode;
+use RDF::Redland::LiteralNode;
+use RDF::Redland::XMLLiteralNode;
 use RDF::Redland::Parser;
 use RDF::Redland::Query;
 use RDF::Redland::QueryResults;
@@ -80,7 +84,9 @@ sub message ($$$$$$$$$) {
 
 package RDF::Redland;
 
-use vars qw($Debug $World $Error_Sub $Warning_Sub);
+use vars qw($VERSION $Debug $World $Error_Sub $Warning_Sub);
+
+$VERSION= eval sprintf("%s.%02d_%02d_%02d", split(/\./, "1.0.2.1"));
 
 $Debug=0;
 
@@ -92,24 +98,6 @@ $Warning_Sub=undef;
 
 $Log_Sub=undef;
 
-sub set_error_handler ($) {
-  $Error_Sub=shift;
-}
-
-sub set_warning_handler ($) {
-  $Warning_Sub=shift;
-}
-
-# Internal
-sub set_log_handler ($) {
-  $Log_Sub=shift;
-}
-
-sub reset_log_handler () {
-  $Log_Sub=undef;
-}
-
-
 =pod
 
 =head1 NAME
@@ -128,12 +116,68 @@ RDF::Redland - Redland RDF Class
 
 This class initialises the Redland RDF classes.
 
+See the main classes for full detail:
+L<RDF::Redland::Node>, 
+L<RDF::Redland::BlankNode>, L<RDF::Redland::URINode>,
+L<RDF::Redland::LiteralNode>, L<RDF::Redland::XMLLiteralNode>,
+L<RDF::Redland::URI>,
+L<RDF::Redland::Statement>, L<RDF::Redland::Model>,
+L<RDF::Redland::Storage>, L<RDF::Redland::Parser>,
+L<RDF::Redland::Query>, L<RDF::Redland::QueryResults>,
+L<RDF::Redland::Iterator>, L<RDF::Redland::Stream>
+and L<RDF::Redland::RSS>.
+
 =head1 STATIC METHODS
 
 =over
 
+=item set_log_handler SUB
+
+Set I<SUB> as the subroutine to be called on any Redland error, warning
+or log message.  The subroutine must have the followign signature:
+
+
+  sub handler ($$$$$$$$$) {
+    my($code, $level, $facility, $message, $line, $column, $byte, $file, $uri)=@_;
+    # int error code
+    # int log level
+    # int facility causing the error (parsing, serializing, ...)
+    # string error message
+    # int line number (<0 if not relevant)
+    # int column number (<0 if not relevant)
+    # int byte number (<0 if not relevant)
+    # string file name or undef
+    # string URI or undef
+    
+    # ...do something with the information ...
+  };
+
+  RDF::Redland::set_log_handler(\&handler);
+
+=cut
+
+sub set_log_handler ($) {
+  $Log_Sub=shift;
+}
+
+
+=item reset_log_handler
+
+Reset redland to use the default logging handler, typically printing
+the message to stdout or stderr and exiting on a fatal error.
+
+=cut
+
+sub reset_log_handler () {
+  $Log_Sub=undef;
+}
+
+
 =item set_error_handler SUB
 
+The method set_log_handler is much more flexible than this and includes
+this functionality.
+
 Set I<SUB> as the subroutine to be called on a Redland error with
 the error message as the single argument.  For example:
 
@@ -144,8 +188,18 @@ the error message as the single argument.  For example:
 
 The default if this is not set, is to run die $msg
 
+=cut
+
+sub set_error_handler ($) {
+  $Error_Sub=shift;
+}
+
+
 =item set_warning_handler SUB
 
+The method set_log_handler is much more flexible than this and includes
+this functionality.
+
 Set I<SUB> as the subroutine to be called on a Redland warning with
 the warning message as the single argument.  For example:
 
@@ -156,11 +210,22 @@ the warning message as the single argument.  For example:
 
 The default if this is not set, is to run warn $msg
 
+=cut
+
+sub set_warning_handler ($) {
+  $Warning_Sub=shift;
+}
+
+=pod
+
 =back
 
 =head1 SEE ALSO
 
-L<RDF::Redland::Node>, L<RDF::Redland::URI>,
+L<RDF::Redland::Node>, 
+L<RDF::Redland::BlankNode>, L<RDF::Redland::URINode>,
+L<RDF::Redland::LiteralNode>, L<RDF::Redland::XMLLiteralNode>,
+L<RDF::Redland::URI>,
 L<RDF::Redland::Statement>, L<RDF::Redland::Model>,
 L<RDF::Redland::Storage>, L<RDF::Redland::Parser>,
 L<RDF::Redland::Query>, L<RDF::Redland::QueryResults>,
