@@ -2,7 +2,7 @@
 #
 # Model.pm - Redland Perl RDF Model module
 #
-# $Id: Model.pm,v 1.38 2004/07/07 22:20:22 cmdjb Exp $
+# $Id: Model.pm,v 1.42 2005/02/24 12:31:29 cmdjb Exp $
 #
 # Copyright (C) 2000-2003 David Beckett - http://purl.org/net/dajobe/
 # Institute for Learning and Research Technology - http://www.ilrt.org/
@@ -589,6 +589,44 @@ sub query_execute ($$) {
 }
 
 
+=item load URI [SYNTAX-NAME [ MIME-TYPE [SYNTAX-URI [HANDLER ]]]
+
+Load content from I<URI> into the model, guessing the parser.
+
+=cut
+
+sub load ($$;$$$$) {
+  my($self,$uri,$name,$type,$syntax_uri,$handler)=@_;
+  my $ruri=$uri ? $uri->{URI} : undef;
+  my $rsyntax_uri=$syntax_uri ? $syntax_uri->{URI} : undef;
+
+  if($handler) {
+    &RDF::Redland::set_log_handler($handler);
+  }
+  my $rc=&RDF::Redland::CORE::librdf_model_load($self->{MODEL},$ruri, $name, $type, $rsyntax_uri);
+  if($handler) {
+    &RDF::Redland::reset_log_handler();
+  }
+  return $rc;
+}
+
+
+=item to_string [BASE-URI [SYNTAX-NAME [ MIME-TYPE [SYNTAX-URI]]]
+
+Serialize the model to a syntax.  If no serializer name is given,
+the default serializer RDF/XML is used.
+
+=cut
+
+sub to_string($;$$$$) {
+  my($self,$uri,$name,$type,$syntax_uri)=@_;
+  my $ruri=$uri ? $uri->{URI} : undef;
+  my $rsyntax_uri=$syntax_uri ? $syntax_uri->{URI} : undef;
+
+  return &RDF::Redland::CORE::librdf_model_to_string($self->{MODEL}, $ruri, $name, $type, $rsyntax_uri);
+}
+
+
 =pod
 
 =back
