@@ -2,9 +2,9 @@
 #
 # QueryResults.pm - Redland Perl RDF Query Results module
 #
-# $Id: QueryResults.pm,v 1.8 2005/02/16 14:53:47 cmdjb Exp $
+# $Id: QueryResults.pm,v 1.10 2005/06/06 19:34:08 cmdjb Exp $
 #
-# Copyright (C) 2004 David Beckett - http://purl.org/net/dajobe/
+# Copyright (C) 2004-2005 David Beckett - http://purl.org/net/dajobe/
 # Institute for Learning and Research Technology - http://www.ilrt.org/
 # University of Bristol - http://www.bristol.ac.uk/
 # 
@@ -232,7 +232,7 @@ sub next_result ($) {
 
 =item as_stream
 
-Return a new RDF::Redland::Stream object returning the query results
+Return a new RDF::Redland::Stream object representing the query results
 as an RDF Graph.
 
 =cut
@@ -278,7 +278,7 @@ sub to_string($;$$) {
   if($format_uri && !ref($format_uri)) {
     $format_uri = RDF::Redland::URI->new($format_uri);
   }
-  $format_uri ||= RDF::Redland::URI->new("http://www.w3.org/TR/2004/WD-rdf-sparql-XMLres-20041221/");
+  $format_uri ||= RDF::Redland::URI->new("http://www.w3.org/2001/sw/DataAccess/rf1/result2");
 
   my $rformat_uri=$format_uri ? $format_uri->{URI} : undef;
 
