@@ -1,7 +1,7 @@
 # 
 # RDF.py - Redland Python RDF module
 #
-# $Id: RDF.py,v 1.100 2005/02/24 14:11:19 cmdjb Exp $
+# $Id: RDF.py,v 1.107 2005/06/06 19:34:15 cmdjb Exp $
 #
 # Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/
 # Institute for Learning and Research Technology - http://www.ilrt.bris.ac.uk/
@@ -70,14 +70,16 @@ from __future__ import generators
   ... do stuff
 
 The Python interface to the Redland RDF library.  See
-  http://www.redland.opensource.ac.uk/
+  http://librdf.org/
 for full details.
 
 The main class that is used is Model which represents the RDF graph
 formed from triples or Statements.  These statements consist of
 three Node objects for resource or literals and can be stored in
 a Storage (persistent or in-memory) as well as serialized to/from
-syntaxes via the Serializer or Parser classes.
+syntaxes via the Serializer or Parser classes.  The Query class
+provides a way to use a query language with a Model, returning
+answers in QueryResults objects.
 
 """
 
@@ -108,7 +110,7 @@ __all__ = [ "Node",
 __version__ = "1.1"
 
 # For pydoc
-__date__ = '$Date: 2005/02/24 14:11:19 $'
+__date__ = '$Date: 2005/06/06 19:34:15 $'
 __author__ = 'Dave Beckett - http://purl.org/net/dajobe, Edd Dumbill <edd@usefulinc.com> and Matt Biddulph <mb@picdiary.com>'
 
 # Package variables [globals]
@@ -384,15 +386,13 @@ class Node(object):
 
   def __eq__(self,other):
     """Equality of an RDF Node compared to another RDF Node."""
-    if other is None:
-      return (self is None)
+    if not isinstance(other, self.__class__):
+      return False
     return (Redland.librdf_node_equals(self._node, other._node) != 0)
 
   def __ne__(self,other):
     """Inequality of an RDF Node compared to another RDF Node."""
-    if other is None:
-      return (self is None)
-    return (Redland.librdf_node_equals(self._node, other._node) == 0)
+    return not self == other
 
   def __hash__(self):
     return hash(str(self))
@@ -563,15 +563,13 @@ class Statement(object):
 
   def __eq__(self,other):
     """Equality of an RDF Statement compared to another RDF Statement."""
-    if other is None:
-      return (self is None)
+    if not isinstance(other, self.__class__):
+      return False
     return (Redland.librdf_statement_equals(self._statement, other._statement) != 0)
 
   def __ne__(self,other):
     """Inequality of an RDF Statement compared to another RDF Statement."""
-    if other is None:
-      return (self is None)
-    return (Redland.librdf_statement_equals(self._statement, other._statement) == 0)
+    return not self == other
 
   def matches(self,other):
     """Comparison of this potentially incomplete RDF Statement compared to another RDF Statement."""
@@ -697,7 +695,7 @@ Create a model using an in-memory storage.
     return Redland.librdf_model_add(self._model, 
         Redland.librdf_new_node_from_node(subject._node),
         Redland.librdf_new_node_from_node(predicate._node),
-        Redland.librdf_new_node_from_node(object._node));
+        Redland.librdf_new_node_from_node(object._node))
 
   def add_typed_literal_statement(self,subject,predicate,
                                   string,xml_language=None,datatype=None):
@@ -1093,7 +1091,7 @@ Create a model using an in-memory storage.
   def to_string(self, base_uri=None, name="", mime_type="", type_uri=None):
     """Serialize the Model to a syntax.
 
-       print model.to_string(base_uri="http://example.org/base");
+       print model.to_string(base_uri="http://example.org/base")
 
        If no serializer name is given, the default serializer RDF/XML is used.
    """
@@ -1321,11 +1319,11 @@ class Stream(object):
     if _debug:
       print "Creating RDF.Stream for object",object, "creator",creator
 
-    self._stream=object;
+    self._stream=object
 
     # Keep around a reference to the object that created the stream
     # so that Python does not destroy them before us.
-    self.creator=creator;
+    self.creator=creator
 
   def context_iter(self):
     """Return an iterator over this stream that
@@ -1481,10 +1479,10 @@ and Hash storage:
         args.has_key('name') and 
         args.has_key('options_string')):
       self._storage=Redland.librdf_new_storage(_world._world,
-          args['storage_name'], args['name'], args['options_string']);
+          args['storage_name'], args['name'], args['options_string'])
     elif args.has_key('storage'):
       self._storage=Redland.librdf_new_storage_from_storage(
-          args['storage']._storage);
+          args['storage']._storage)
     else:
       raise RedlandError("Creating Storage failed - illegal arguments")
 
@@ -1515,8 +1513,8 @@ class HashStorage(Storage):
   hash-type is "memory" or "bdb") and any other options.
   """
   def __init__(self, hash_name, options=""):
-    return Storage.__init__(self, name = hash_name, storage_name = "hashes",
-            options_string = options)
+    Storage.__init__(self, name = hash_name, storage_name = "hashes",
+                     options_string = options)
 
 
 class MemoryStorage(Storage):
@@ -1533,8 +1531,8 @@ class MemoryStorage(Storage):
   Class of memory Storage with optional name, additional options.
   """
   def __init__(self, mem_name = "", options_string = ""):
-    return Storage.__init__(self, name = mem_name, storage_name = "memory",
-            options_string = options_string)
+    Storage.__init__(self, name = mem_name, storage_name = "memory",
+                     options_string = options_string)
 
 
 class FileStorage(Storage):
@@ -1546,8 +1544,8 @@ class FileStorage(Storage):
   Class of file Storage with required name, additional options.
   """
   def __init__(self, mem_name, options_string = ""):
-    return Storage.__init__(self, name = mem_name, storage_name = "file",
-            options_string = options_string)
+    Storage.__init__(self, name = mem_name, storage_name = "file",
+                     options_string = options_string)
 
 
 class Uri(object):
@@ -1622,15 +1620,13 @@ Copy an existing URI uri1.
   
   def __eq__(self,other):
     """Equality of RDF URI to another RDF URI."""
-    if other is None:
-      return (self is None)
+    if not isinstance(other, self.__class__):
+      return False
     return (Redland.librdf_uri_equals(self._reduri, other._reduri) != 0)
 
   def __ne__(self,other):
     """Inequality of RDF URI to another RDF URI."""
-    if other is None:
-      return (self is None)
-    return (Redland.librdf_uri_equals(self._reduri, other._reduri) == 0)
+    return not self == other
 
 # end class Uri
 
@@ -1820,19 +1816,19 @@ optional.  When any are given, they must all match.
 
 class RDFXMLParser(Parser):
   def __init__(self, uri = None):
-    return Parser.__init__(self, name = "rdfxml", mime_type="", uri=uri)
+    Parser.__init__(self, name = "rdfxml", mime_type="", uri=uri)
 
 class NTriplesParser(Parser):
   def __init__(self, uri = None):
-    return Parser.__init__(self, name = "ntriples", mime_type="text/plain", uri=uri)
+    Parser.__init__(self, name = "ntriples", mime_type="text/plain", uri=uri)
 
 class TurtleParser(Parser):
   def __init__(self, uri = None):
-    return Parser.__init__(self, name = "turtle", mime_type="application/x-turtle", uri=uri)
+    Parser.__init__(self, name = "turtle", mime_type="application/x-turtle", uri=uri)
 
 class RSSTagSoupParser(Parser):
   def __init__(self, uri = None):
-    return Parser.__init__(self, name = "rss-tag-soup", mime_type="", uri=uri)
+    Parser.__init__(self, name = "rss-tag-soup", mime_type="", uri=uri)
 
 
 class Query(object):
@@ -1841,7 +1837,8 @@ class Query(object):
   import RDF
 
   q1 = RDF.Query("SELECT ?a ?c WHERE (?a dc:title ?c) USING dc FOR <http://purl.org/dc/elements/1.1/>")
-  q2 = RDF.Query("- - -", name="triples")
+  q2 = RDF.Query("- - -", query_language="triples")
+  q3 = RDF.Query("select $a where ...", query_language="sparql")
 
   results=q1.execute(model)
   for result in results:
@@ -1891,14 +1888,14 @@ class Query(object):
 class RDQLQuery(Query):
   """Redland RDQL Query class"""
   def __init__(self, querystring, base_uri=None):
-    return Query.__init__(self, querystring = querystring, base_uri = base_uri,
-            query_language = "rdql")
+    Query.__init__(self, querystring = querystring, base_uri = base_uri,
+                   query_language = "rdql")
 
 class SPARQLQuery(Query):
   """Redland SPARQL Query class"""
   def __init__(self, querystring, base_uri=None):
-    return Query.__init__(self, querystring = querystring, base_uri = base_uri,
-            query_language = "sparql")
+    Query.__init__(self, querystring = querystring, base_uri = base_uri,
+                   query_language = "sparql")
 
 
 class QueryResults(object):
@@ -2044,7 +2041,7 @@ class QueryResults(object):
       import Redland_python
       format_uri = Uri(string=Redland_python.unicode_to_bytes(format_uri))
     else:
-      format_uri = Uri(string="http://www.w3.org/TR/2004/WD-rdf-sparql-XMLres-20041221/")
+      format_uri = Uri(string="http://www.w3.org/2001/sw/DataAccess/rf1/result2")
     if format_uri is not None:
       rformat_uri = format_uri._reduri
     else:
@@ -2170,6 +2167,18 @@ class Serializer(object):
         raise TypeError("uri must be string or RDF.Uri")
     Redland.librdf_serializer_set_feature(self._serializer,uri._reduri,value)
 
+  def set_namespace(self, prefix, uri):
+    """Set a namespace prefix and URI for the Serializer to use."""
+    if not isinstance(uri, Uri):
+      if type(uri) is str:
+        uri = Uri(string=uri)
+      elif type(uri) is unicode:
+        import Redland_python
+        uri = Uri(string=Redland_python.unicode_to_bytes(uri))
+      else:
+        raise TypeError("uri must be string or RDF.Uri")
+    Redland.librdf_serializer_set_namespace(self._serializer, uri._reduri, prefix)
+
 
 # end class Serializer
 
@@ -2181,8 +2190,7 @@ class NTriplesSerializer(Serializer):
      ser=RDF.NTriplesSerializer()
   """
   def __init__(self):
-    return Serializer.__init__(self, name = "ntriples", mime_type = "",
-            uri = None)
+    Serializer.__init__(self, name = "ntriples", mime_type = "", uri = None)
 
 
 class RDFXMLSerializer(Serializer):
@@ -2192,7 +2200,7 @@ class RDFXMLSerializer(Serializer):
      ser=RDF.RDFXMLSerializer()
   """
   def __init__(self):
-    return Serializer.__init__(self, name = "rdfxml", mime_type = "", uri = None)
+    Serializer.__init__(self, name = "rdfxml", mime_type = "", uri = None)
 
 class RDFXMLAbbrevSerializer(Serializer):
   """Redland RDF/XML with abbreviations Serializer class
@@ -2201,7 +2209,7 @@ class RDFXMLAbbrevSerializer(Serializer):
      ser=RDF.RDFXMLAbbrevSerializer()
   """
   def __init__(self):
-    return Serializer.__init__(self, name = "rdfxml-abbrev", mime_type = "", uri = None)
+    Serializer.__init__(self, name = "rdfxml-abbrev", mime_type = "", uri = None)
 
 class RSS10Serializer(Serializer):
   """Redland RSS 1.0 Serializer class
@@ -2210,7 +2218,7 @@ class RSS10Serializer(Serializer):
      ser=RDF.RSS10Serializer()
   """
   def __init__(self):
-    return Serializer.__init__(self, name = "rss-1.0", uri = None)
+    Serializer.__init__(self, name = "rss-1.0", uri = None)
 
 
 class NS(object):
